#!/bin/sh

# Licensed Material - Property of IBM
# 5724-M24
# (c) Copyright IBM Corp. 2006. All rights reserved.
# US Government Users Restricted Rights - Use, duplication or
# disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
# DECLARE and INITIALIZE GLOBAL VARIABLES
set +x

MSMDEBUG=
USELOG=N
ISSUBSHELL=N
ISSUBSHELLHELP=N
HELP=N
MSMLOGFILE=$0.log
DB2JAVA=
DB2JAVAFILES=

# ERRORCODES
MSM_DB2DETECTIONERROR=3
MSM_DB2NOINSTANCESET=4
MSM_JARNOTFOUND=5

localinit() {
	DB2JAVA=/java/

	DB2JAVAFILES="db2java.zip"

	# Change all .sh files to user executable
	find . -name "*.sh" | while read f;do chmod u+x $f;done
}

testMSM() {
	$MSMDEBUG echo "-->setup JAR file paths"
	MILLISMIGRATIONTOOLS=./monWBIDSMillisMigrationTools.jar
	EMFJAR=./emf.jar
	IBMJAXRPCCLIENT=./ibm-jaxrpc-client.jar
	LIFECYCLESPIJAR=./lib/monLifecycleSPI.jar
	MONMODELJAR=./lib/monModel.jar
	MONEVENTDEF=./lib/monEventDefinition.jar
	MONREPOSITORYJAR=./lib/monrepository.jar
	MONDEPLOYMENTTOOLSJAR=./lib/monWBIDSDeploymentTools.jar
	MONMMUTILITIESJAR=./lib/monMMUtilities.jar
	MONUTIL=./lib/monutil.jar
	
	if [ ! -e $MILLISMIGRATIONTOOLS ]
	then
		echo monWBIDSMillisMigrationTools.jar is not found under the current directory.
		return $MSM_JARNOTFOUND
	fi
	
	if [ ! -e $EMFJAR ]
	then
		echo emf.jar is not found under the current directory.
		return $MSM_JARNOTFOUND
	fi
	
	if [ ! -e $IBMJAXRPCCLIENT ]
	then
		echo ibm-jaxrpc-client.jar is not found under the current directory.
		return $MSM_JARNOTFOUND
	fi
	
	if [ ! -e $LIFECYCLESPIJAR ]
	then
		echo monLifecycleSPI.jar is not found under the current directory.
		return $MSM_JARNOTFOUND
	fi
	
	if [ ! -e $MONMODELJAR ]
	then
		echo monModel.jar is not found under the current directory.
		return $MSM_JARNOTFOUND
	fi
	
	if [ ! -e $MONEVENTDEF ]
	then
		echo monEventDefinition.jar is not found under the current directory.
		return $MSM_JARNOTFOUND
	fi
	
	if [ ! -e $MONREPOSITORYJAR ]
	then
		echo monrepository.jar is not found under the current directory.
		return $MSM_JARNOTFOUND
	fi
	
	if [ ! -e $MONDEPLOYMENTTOOLSJAR ]
	then
		echo monWBIDSDeploymentTools.jar is not found under the current directory.
		return $MSM_JARNOTFOUND
	fi
	
	if [ ! -e $MONMMUTILITIESJAR ]
	then
		echo monMMUtilities.jar is not found under the current directory.
		return $MSM_JARNOTFOUND
	fi
	
	if [ ! -e $MONUTIL ]
	then
		echo monutil.jar is not found under the current directory.
		return $MSM_JARNOTFOUND
	fi
	
	CLASSPATH=$CLASSPATH:$MILLISMIGRATIONTOOLS:$LIFECYCLESPIJAR:$MONMODELJAR:$MONREPOSITORYJAR:$MONMMUTILITIESJAR:$EMFJAR:$IBMJAXRPCCLIENT:$MONUTIL:$MONEVENTDEF:$MONDEPLOYMENTTOOLSJAR
	export CLASSPATH
	
	java com.ibm.wbimonitor.dataservices.migration.milliseconds.Runner -test

	$MSMDEBUG echo "setup JAR file paths-->"
	return $RETVAL
}

setupDB2() {
	$MSMDEBUG echo "-->setupDB2"

	local DB2PATHS="$DB2DIR /usr/opt/db2_08_01"
	local RETVAL=$MSM_DB2DETECTIONERROR
	local DONEFOR=0

	local DB2CP=
	local DB2SELECTEDPATH=
	local TESTFILE=
	local CHECKDB2DIR

	
	#check for DB2 instance
	if test "$DB2INSTANCE" = ""
	then
		$MSMDEBUG echo "DB2 Instance Not Set"
		set RETVAL=$MSM_DB2NOINSTANCESET
		return $RETVAL
	fi


	#check for location of DB2
	CHECKDB2DIR=`which db2|sed "s!/bin/db2!!"`

	RETVAL=$?

	if ! test $RETVAL -eq 0
	then
		$MSMDEBUG echo "db2 is not in the current path."
		return $MSM_DB2DETECTIONERROR	
	fi

	# First try the which result, then the expected DB2DIR
	# then finally the hard coded V8 directory.
	DB2PATHS="$CHECKDB2DIR $DB2DIR /usr/opt/db2_08_01"

	#LOOP THROUGH DB2PATHS
	for p in $DB2PATHS
	do
		DONEFOR=0
		#CHECK JAVAFILES

		for j in $DB2JAVAFILES
		do
			TESTFILE=$p$DB2JAVA$j
			$MSMDEBUG echo "testing file $TESTFILE"
			if ! test DONEFOR -eq 1 && ! test -e $TESTFILE 
			then
				$MSMDEBUG echo "FILE NOT FOUND"
				DONEFOR=1
				continue 2
			else
				DB2CP=$DB2CP:$TESTFILE
			fi
		done

		break

	done

	if test $RETVAL = 0 
	then
		CLASSPATH=$CLASSPATH$DB2CP
		export CLASSPATH
		$MSMDEBUG echo "CLASSPATH:::$CLASSPATH"
	fi

	$MSMDEBUG echo "setupDB2-->"

	return $RETVAL
}



# ******************* MAIN FUNCTION BODY***************


# Run this program again.
# This time we will log any output to $0.log
# We will also run this in a subshell, which will create
# a file which will be used to modify
# the path and classpath variables later on.



MSM_RETVAL=0
local OLDCLASSPATH=$CLASSPATH

#*************************************************
#	TESTING MSM SPECIFIC DEPLOYMENT JARS
#*************************************************

testMSM

MSM_RETVAL=$?

$MSMDEBUG echo "testMSM\($MSM_RETVAL\)"

if ! test $MSM_RETVAL -eq 0
then
	exit $MSM_RETVAL
fi

#*************************************************
#	INITIALIZATION
#*************************************************

localinit

#*************************************************
#	SETUP DB2
#*************************************************

MSM_RETVAL=1
MSM_NUMTRY=0

setupDB2

MSM_RETVAL=$?

$MSMDEBUG echo "setupDB2\($MSM_RETVAL\)"

if ! test $MSM_RETVAL = 0 
then
	$MSMDEBUG echo "-->Error"
	exit $MSM_RETVAL 
	$MSMDEBUG echo "Error-->"
fi
		
export DB2CODEPAGE=1208
export LIBPATH=.:$LIBPATH

$MSMDEBUG echo "CLASSPATH=$CLASSPATH "

java com.ibm.wbimonitor.dataservices.migration.milliseconds.Runner

CLASSPATH=$OLDCLASSPATH
export CLASSPATH		
