#!/bin/sh

# ************************************************************************
#  Licensed Material - Property of IBM
# 
#  5724-M24
# 
#  (c) Copyright IBM Corp. 2006,2007.  All rights reserved.
# 
#  US Government Users Restricted Rights - Use, duplication or
#  disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
# ************************************************************************
# 
# ************************************************************************
#  Upgrade Monitor Dashboard 6.0.2 to 6.0.2.1
# ************************************************************************

# set defaults 
WARN_ONLY=no
MY_DIR=`pwd`
LOGS=$MY_DIR/logs/dashbd.log
MON_HOME=/usr/IBM/WebSphere/Monitor
PROFILE_NAME=wp_profile
WAS_HOME=/usr/IBM/WAS
WPS_HOME=/usr/IBM/PortalServer
PROFILE_HOME=$WAS_HOME/profiles/$PROFILE_NAME
PORTAL_SERVER=WebSphere_Portal
ADMIN_ID=wpsadmin
ADMIN_PW=wpsadmin
CONFIG_HOST=localhost
CONFIG_PORT=9081

# define input prompts       
MON_HOME_PROMPT="Type the path to the WebSphere Business Monitor installation directory"
WAS_HOME_PROMPT="Type the path to the WebSphere Application Server installation directory"
PROFILE_PROMPT="Type the path to the profile that the contains the Portal Server"
PORTAL_HOME_PROMPT="Type the path to the Portal Server installation directory"
CONFIG_PORT_PROMPT="Type the port number used to access the WebSphere Portal configuration utility"
WPS_PW_PROMPT="Type the password for the Portal Admin user"


# ************************************************************************
# Begin function definitions
# ************************************************************************

# ************************************************************************
# Write messages to log file
# ************************************************************************
logecho ()
{
  echo "++++++++++++++++++++++++++++++++++++++++++++++++++++++++" >> $LOGS
  echo $1 >> $LOGS
  echo "++++++++++++++++++++++++++++++++++++++++++++++++++++++++" >> $LOGS
  date +%T >> $LOGS
  return 0
}

# ************************************************************************
# Copy log file to Monitor home
# ************************************************************************
copylog ()
{
   if [ "$MON_HOME" != "" ]
   then
      MON_LOG_DIR=$MON_HOME/update/6.0.2.1-WBI-MONITOR-UPK417107.install/logs
      if [ ! -d  $MON_LOG_DIR ] 
      then 
         mkdir -p $MON_LOG_DIR
      fi 
      cp $LOGS $MON_LOG_DIR
   fi
}

# ************************************************************************
# Handle command failures
# ************************************************************************
cmdFailed()
{
  echo +++ Error: \'$CMD\' returned $1
  if [ $WARN_ONLY = "yes" ]
  then
    return $1
  fi 
  failed 8
}

# ************************************************************************
# Check return code from command execution
# ************************************************************************
checkCmdErr()
{
  if [ $1 -ne 0 ]  
  then
    cmdFailed $1
  fi
}

# ************************************************************************
# Print failure message and get out 
# ************************************************************************
failed()
{
    echo Upgrade failed! 
    echo "++++++++++++++++++++++++++++++++++++++++++++++++++++++++" >> $LOGS
    echo Upgrade failed! >> $LOGS
    echo "++++++++++++++++++++++++++++++++++++++++++++++++++++++++" >> $LOGS
    date >> $LOGS
    copylog
    exit $1
}

# ************************************************************************
# End function definitions
# ************************************************************************

# ************************************************************************
# Begin main code 
# ************************************************************************

# set up logs directory
if [ ! -d  $MY_DIR/logs ] 
then 
   mkdir -p $MY_DIR/logs
fi 

echo Start Monitor Dashboard 6.0.2.1 upgrade...
echo "++++++++++++++++++++++++++++++++++++++++++++++++++++++++" > $LOGS
echo Start Monitor Dashboard 6.0.2.1 upgrade... >> $LOGS
echo "++++++++++++++++++++++++++++++++++++++++++++++++++++++++" >> $LOGS
date >> $LOGS

# get Monitor home
echo $MON_HOME_PROMPT [enter=$MON_HOME ]: 
read RESPONSE
if [ "$RESPONSE" != "" ] 
then
   MON_HOME=$RESPONSE
fi
if [ ! -d $MON_HOME ]
then 
   echo +++ Error: Monitor home - $MON_HOME does NOT exist!
   logecho "+++ Error: Monitor home - $MON_HOME does NOT exist!"
   MON_HOME=
   failed 8
fi
       
# get WAS variables
echo $WAS_HOME_PROMPT [enter=$WAS_HOME ]: 
read RESPONSE
if [ "$RESPONSE" != "" ] 
then
   WAS_HOME=$RESPONSE
fi
if [ ! -d $WAS_HOME ]
then 
   echo +++ Error: WAS home - $WAS_HOME does NOT exist!
   logecho "+++ Error: WAS home - $WAS_HOME does NOT exist!"
   failed 8
fi
PROFILE_HOME=$WAS_HOME/profiles/$PROFILE_NAME
echo $PROFILE_PROMPT [enter=$PROFILE_HOME ]: 
read RESPONSE
if [ "$RESPONSE" != "" ] 
then
   PROFILE_HOME=$RESPONSE
fi
if [ ! -d $PROFILE_HOME ]
then 
   echo +++ Error: Profile home - $PROFILE_HOME does NOT exist!
   logecho "+++ Error: Profile home - $PROFILE_HOME does NOT exist!"
   failed 8
fi

# get Portal variables
echo $PORTAL_HOME_PROMPT [enter=$WPS_HOME ]: 
read RESPONSE
if [ "$RESPONSE" != "" ] 
then
   WPS_HOME=$RESPONSE
fi
if [ ! -d $WPS_HOME ]
then 
   echo +++ Error: Portal home - $WPS_HOME does NOT exist!
   logecho "+++ Error: Portal home - $WPS_HOME does NOT exist!"
   failed 8
fi
echo $WPS_PW_PROMPT [enter=$ADMIN_PW ]: 
read RESPONSE
if [ "$RESPONSE" != "" ] 
then
   ADMIN_PW=$RESPONSE
fi
echo $CONFIG_PORT_PROMPT [enter=$CONFIG_PORT ]: 
read RESPONSE
if [ "$RESPONSE" != "" ] 
then
   CONFIG_PORT=$RESPONSE
fi
CONFIG_URL=http://$CONFIG_HOST:$CONFIG_PORT/wps/config

# stop the server so we can copy files
echo Stopping server $PORTAL_SERVER...
logecho "Stopping server $PORTAL_SERVER..."
CMD="$PROFILE_HOME/bin/stopServer.sh $PORTAL_SERVER -username $ADMIN_PW -password $ADMIN_PW"
$CMD >>$LOGS 2>&1 

# copy files
echo Copying files...
logecho "Copying files..."
CMD="cp -f files/dashboardclient.war $WPS_HOME/installableApps" 
$CMD >>$LOGS 2>&1
checkCmdErr $?
CMD="cp -f files/dashboardjsr168.war $WPS_HOME/installableApps" 
$CMD >>$LOGS 2>&1
checkCmdErr $?

CMD="cp -f jars/*.* $WAS_HOME/lib"
$CMD >>$LOGS 2>&1
checkCmdErr $?
CMD="cp -f files/MON.product $WAS_HOME/properties/version" 
$CMD >>$LOGS 2>&1
checkCmdErr $?

echo Starting server $PORTAL_SERVER...
logecho "Starting server $PORTAL_SERVER..."
CMD="$PROFILE_HOME/bin/startServer.sh $PORTAL_SERVER -username $ADMIN_PW -password $ADMIN_PW"
$CMD >>$LOGS 2>&1 
checkCmdErr $?

# Deploy WAR files
echo Deploying WAR files...
logecho "Deploying WAR files..."
CMD="$WPS_HOME/bin/xmlaccess.sh -in files/update_WBIMon.xml -user $ADMIN_ID -pwd $ADMIN_PW -url $CONFIG_URL" 
$CMD >>$LOGS 2>&1 
checkCmdErr $?

echo Upgrade finished.
logecho "Upgrade finished."
copylog
exit 0
