#!/bin/sh

# ************************************************************************
#  Licensed Material - Property of IBM
# 
#  5724-M24
# 
#  (c) Copyright IBM Corp. 2006, 2007.  All rights reserved.
# 
#  US Government Users Restricted Rights - Use, duplication or
#  disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
# ************************************************************************
# 
# ************************************************************************
#  Upgrade Monitor Server 6.0.2 to 6.0.2.1
# ************************************************************************

# ************************************************************************
# Begin function definitions
# ************************************************************************
# 
#  Manually "deploy" a WCCM plugin to the administrative console's EAR. 
#  You will need to execute "iscdeploy -restore" afterwards to complete
#  the deployment.
# 
#  USAGE:
#
#    manualISCDeploy pluginWAR pluginId jarPrefix
# 
#      pluginWAR  Path the the plugin's WAR file
#      pluginId   The plugin's Id
#      jarPrefix  Prefix added to the plugin's jars when deployed.
# 
#  The WAS_HOME1 environment variable must be set prior to invocation.
# ************************************************************************
manualISCDeploy ()
{
  PLUGIN_WAR=$1
  PLUGIN_ID=$2
  JAR_PREFIX=$3
  ADMINCONSOLE_WAR=${WAS_HOME1}/systemApps/adminconsole.ear/adminconsole.war
  JAR_EXE=${WAS_HOME1}/java/bin/jar

  echo Using the following settings:
  echo   PLUGIN_WAR       = $PLUGIN_WAR
  echo   PLUGIN_ID        = $PLUGIN_ID
  echo   JAR_PREFIX       = $JAR_PREFIX
  echo   WAS_HOME1         = $WAS_HOME1
  echo   ADMINCONSOLE_WAR = $ADMINCONSOLE_WAR
  echo   JAR_EXE          = $JAR_EXE

  # this script has to change directories to overcome limitations
  # in jar.exe, so I save the current directory name here
  SAVE_CD=`pwd`

  # change to the admin console's war directory
  cd $ADMINCONSOLE_WAR

  # extract NLS files
  $JAR_EXE xvf $PLUGIN_WAR $PLUGIN_ID
  SAVE_RC=$?
  if [ $SAVE_RC -ne 0 ]
  then 
    return $SAVE_RC
  fi

  # extract pre-compiled JSP files
  $JAR_EXE xvf $PLUGIN_WAR WEB-INF/classes
  SAVE_RC=$?
  if [ $SAVE_RC -ne 0 ]
  then 
    return $SAVE_RC
  fi

  # extract dependent jars to temp directory
  # create temp directory and change directory to it
  TEMP_DIR=/tmp/monitorUpgrade
  mkdir $TEMP_DIR
  cd $TEMP_DIR

  # extract jars
  $JAR_EXE xvf $PLUGIN_WAR WEB-INF/lib
  SAVE_RC=$?
  if [ $SAVE_RC -ne 0 ]
  then 
    return $SAVE_RC
  fi

  # rename jars
  cd WEB-INF/lib
  for file in *
  do
    mv $file ${JAR_PREFIX}-$file
  done

  # move jars
  mv * ${ADMINCONSOLE_WAR}/WEB-INF/lib
  SAVE_RC=$?
  if [ $SAVE_RC -ne 0 ]
  then 
    return $SAVE_RC
  fi

  # cleanup temp directory
  cd $SAVE_CD
  rm -r $TEMP_DIR
  
  # cd to plugin WEB-INF directory
  PLUGIN_WEBINF_DIR=${ADMINCONSOLE_WAR}/WEB-INF/${PLUGIN_ID}
  cd $PLUGIN_WEBINF_DIR

  # extract needed files and move to the correct location
  $JAR_EXE xvf $PLUGIN_WAR WEB-INF/console-defs.xml
  $JAR_EXE xvf $PLUGIN_WAR WEB-INF/plugin.dtd
  $JAR_EXE xvf $PLUGIN_WAR WEB-INF/plugin.properties
  $JAR_EXE xvf $PLUGIN_WAR WEB-INF/plugin.xml
  $JAR_EXE xvf $PLUGIN_WAR WEB-INF/plugin_de.properties
  $JAR_EXE xvf $PLUGIN_WAR WEB-INF/plugin_en.properties
  $JAR_EXE xvf $PLUGIN_WAR WEB-INF/plugin_es.properties
  $JAR_EXE xvf $PLUGIN_WAR WEB-INF/plugin_fr.properties
  $JAR_EXE xvf $PLUGIN_WAR WEB-INF/plugin_it.properties
  $JAR_EXE xvf $PLUGIN_WAR WEB-INF/plugin_ja.properties
  $JAR_EXE xvf $PLUGIN_WAR WEB-INF/plugin_ko.properties
  $JAR_EXE xvf $PLUGIN_WAR WEB-INF/plugin_pt.properties
  $JAR_EXE xvf $PLUGIN_WAR WEB-INF/plugin_pt_BR.properties
  $JAR_EXE xvf $PLUGIN_WAR WEB-INF/plugin_zh.properties
  $JAR_EXE xvf $PLUGIN_WAR WEB-INF/plugin_zh_TW.properties
  $JAR_EXE xvf $PLUGIN_WAR WEB-INF/struts-config.xml
  $JAR_EXE xvf $PLUGIN_WAR WEB-INF/validation.xml
  SAVE_RC=$?
  if [ $SAVE_RC -ne 0 ]
  then 
    return $SAVE_RC
  fi
  
  # move plugin files from WEB-INF/ to current dir   
  mv WEB-INF/* .
  SAVE_RC=$?
  if [ $SAVE_RC -ne 0 ]
  then 
    return $SAVE_RC
  fi
  # delete old copy of web.xml that was copied from WEB-INF/
  rm web.xml 

  # add needed file to com.ibm.ws.console.core plugin
  cp console-defs.xml ../com.ibm.ws.console.core/${PLUGIN_ID}-console-defs.xml
  SAVE_RC=$?
  if [ $SAVE_RC -ne 0 ]
  then 
    return $SAVE_RC
  fi

  # extract web.xml
  $JAR_EXE xvf $PLUGIN_WAR WEB-INF/web.xml
  SAVE_RC=$?
  if [ $SAVE_RC -ne 0 ]
  then 
    return $SAVE_RC
  fi

  # restore original directory
  cd $SAVE_CD

  # return from manualISCDeploy
  return 0
}

# ************************************************************************
# Write messages to log file
# ************************************************************************
logecho ()
{
  echo "++++++++++++++++++++++++++++++++++++++++++++++++++++++++" >> $MY_LOG
  echo $1 >> $MY_LOG
  echo "++++++++++++++++++++++++++++++++++++++++++++++++++++++++" >> $MY_LOG
  date +%T >> $MY_LOG
  return 0
}

# ************************************************************************
# Copy log file to Monitor home
# ************************************************************************
copylog ()
{
   if [ "$MON_HOME" != "" ]
   then
      MON_LOG_DIR=$MON_HOME/update/6.0.2.1-WBI-MONITOR-UPK417107.install/logs
      if [ ! -d  $MON_LOG_DIR ] 
      then 
         mkdir -p $MON_LOG_DIR
      fi 
      cp $MY_LOG $MON_LOG_DIR
   fi
}

# ************************************************************************
# Check return code from command execution
# ************************************************************************
checkCmdErr ()
{
  if [ $1 -ne 0 ]
  then 
    echo Error: command failed, return code = $1
    logecho "+++ Error: command failed, return code = $1"
    failed 8
  fi
  return 0
}

# ************************************************************************
# Print failure message and get out 
# ************************************************************************
failed()
{
    echo Upgrade failed! 
    echo "++++++++++++++++++++++++++++++++++++++++++++++++++++++++" >> $MY_LOG
    echo Upgrade failed! >> $MY_LOG
    echo "++++++++++++++++++++++++++++++++++++++++++++++++++++++++" >> $MY_LOG
    date >> $MY_LOG
    copylog
    exit $1
}
# ************************************************************************
# End function definitions
# ************************************************************************


# ************************************************************************
# Begin main code 
# ************************************************************************

# set up logs directory
MY_DIR=`pwd`
if [ ! -e  $MY_DIR/logs ] 
then 
   mkdir -p $MY_DIR/logs
fi 
MY_LOG=$MY_DIR/logs/monsrv.log

echo Start Monitor Server 6.0.2.1 upgrade...
echo "++++++++++++++++++++++++++++++++++++++++++++++++++++++++" > $MY_LOG
echo Start Monitor Server 6.0.2.1 upgrade... >> $MY_LOG
echo "++++++++++++++++++++++++++++++++++++++++++++++++++++++++" >> $MY_LOG
date >> $MY_LOG

# define input prompts       
MON_PROMPT="Type the path to the WebSphere Business Monitor installation directory"
WPS_PROMPT="Type the path to the Process Server installation directory"
PROFILE_PROMPT="Type the path to the Process Server profile directory"
DMGR_PROMPT="Is this upgrade running on an ND Deployment Manager? Type y or n"
SERVER_PROMPT="Type the server name"

# define default values for standalone server and deployment manager
MON_HOME=/usr/IBM/WebSphere/Monitor
WAS_HOME1=/usr/IBM/WebSphere/ProcServer
WAS_PROFILE_NAME=wbmonitor
WAS_SERVER_NAME=server1
DMGR_PROFILE_NAME=dmgr
DMGR_SERVER_NAME=dmgr

# ask if DMgr is being upgraded       
DMGR_UPGRADE=x
while [ $DMGR_UPGRADE = x ]
do
   echo $DMGR_PROMPT : 
   read RESPONSE
   if [ "$RESPONSE" = "y" ] 
   then
      DMGR_UPGRADE=$RESPONSE
      PROFILE_NAME1=$DMGR_PROFILE_NAME
      SERVER_NAME1=$DMGR_SERVER_NAME
   fi
   if [ "$RESPONSE" = "n" ] 
   then
      DMGR_UPGRADE=$RESPONSE
      PROFILE_NAME1=$WAS_PROFILE_NAME
      SERVER_NAME1=$WAS_SERVER_NAME
   fi
done


# get Monitor home
echo $MON_PROMPT [enter=$MON_HOME ]: 
read RESPONSE
if [ "$RESPONSE" != "" ] 
then
   MON_HOME=$RESPONSE
fi
if [ ! -d $MON_HOME ]
then 
   echo +++ Error: Monitor home - $MON_HOME does NOT exist!
   logecho "+++ Error: Monitor home - $MON_HOME does NOT exist!"
   MON_HOME=
   failed 8
fi

# get WAS home dir 
echo $WPS_PROMPT [enter=$WAS_HOME1 ]: 
read input
if [ "$input" != "" ]
then
   WAS_HOME1=$input
fi

if [ ! -d $WAS_HOME1 ]
then 
   echo +++ Error: Process Server home - $WAS_HOME1 does NOT exist!
   logecho "+++ Error: Process Server home - $WAS_HOME1 does NOT exist!"
   failed 8
fi

# get profile dir                  
WAS_PROFILE_HOME=$WAS_HOME1/profiles/$PROFILE_NAME1
echo $PROFILE_PROMPT [enter=$WAS_PROFILE_HOME ]: 
read input
if [ "$input" != "" ]
then
   WAS_PROFILE_HOME=$input
fi

if [ ! -d $WAS_PROFILE_HOME ]
then 
   echo +++ Error: Profile home - $WAS_PROFILE_HOME does NOT exist!
   logecho "+++ Error: Profile home - $WAS_PROFILE_HOME does NOT exist!"
   failed 8
fi

# get server name                  
echo $SERVER_PROMPT [enter=$SERVER_NAME1 ]: 
read input
if [ "$input" != "" ]
then
   SERVER_NAME1=$input
fi

# setupCmdLine will set WAS_CELL and WAS_NODE
if [ -e ${WAS_PROFILE_HOME}/bin/setupCmdLine.sh ]
then
   . ${WAS_PROFILE_HOME}/bin/setupCmdLine.sh >> $MY_LOG 2>&1
else
   echo +++ Error: ${WAS_PROFILE_HOME}/bin/setupCmdLine.sh does NOT exist!
   logecho "+++ Error: ${WAS_PROFILE_HOME}/bin/setupCmdLine.sh does NOT exist!"
   failed 8
fi
# verify that the server exists
SERVER_HOME=$WAS_PROFILE_HOME/config/cells/$WAS_CELL/nodes/$WAS_NODE/servers/$SERVER_NAME1
if [ ! -d $SERVER_HOME ]
then 
   echo +++ Error: Server home - $SERVER_HOME does NOT exist!
   logecho "+++ Error: Server home - $SERVER_HOME does NOT exist!"
   failed 8
fi

# ************************************************************************
# copy jar files
# ************************************************************************
echo Stop server $SERVER_NAME1 ...
logecho "Stop server $SERVER_NAME1 ..."
. ${WAS_PROFILE_HOME}/bin/setupCmdLine.sh
sh ${WAS_PROFILE_HOME}/bin/stopServer.sh $SERVER_NAME1 >> $MY_LOG 2>&1

echo Copy jar files ... 
logecho "Copy jar files ..."
cp -f ./jars/*.jar ${WAS_HOME1}/lib >> $MY_LOG 2>&1
checkCmdErr $?

cp -f ./files/MON.product ${WAS_HOME1}/properties/version >> $MY_LOG 2>&1
checkCmdErr $?

# ************************************************************************
# copy jar files for MME plugins
# ************************************************************************
echo Copy jar files for MME plugins ... 
logecho "Copy jar files for MME plugins ..."
cp -f -R ./mme/plugins ${WAS_HOME1}/deploytool/itp >> $MY_LOG 2>&1
checkCmdErr $?

# ************************************************************************
# update admin console plugins
# ************************************************************************
curdir=`pwd`
echo Update Admin Console ...
logecho "Update Admin Console ..."
  
# extract the Lifecycle plugin
echo Extracting the Lifecycle Admin Console plugin...
logecho "Extracting the Lifecycle Admin Console plugin..."
manualISCDeploy ${curdir}/files/monitor_lifecycle.war com.ibm.ws.console.monitor.lifecycle lifecycle >> $MY_LOG 2>&1
checkCmdErr $?

# extract the Action Manager plugin
echo Extracting the Action Manager Admin Console plugin...
logecho "Extracting the Action Manager Admin Console plugin..."
manualISCDeploy ${curdir}/files/monAAMAdmin.war com.ibm.ws.console.monitor.actionmgr actionmanager >> $MY_LOG 2>&1
checkCmdErr $?

# execute iscdeploy to merge the plugin configuration files
echo Executing iscdeploy...
logecho "Executing iscdeploy..."
sh ${WAS_PROFILE_HOME}/bin/iscdeploy.sh -restore >> $MY_LOG 2>&1
checkCmdErr $?
echo End updating Admin Console plugins
logecho "End updating Admin Console plugins"

# ************************************************************************
# Restart the server
# ************************************************************************
echo Start server $SERVER_NAME1 ...
logecho "Start server $SERVER_NAME1 ..."
sh ${WAS_PROFILE_HOME}/bin/startServer.sh $SERVER_NAME1 >> $MY_LOG 2>&1
checkCmdErr $?

echo Upgrade finished.
logecho "Upgrade finished."
copylog
exit 0
